#ifndef _PGPEBIZ_H
#define _PGPEBIZ_H

//	Copyright (C) 2004 Networks Associates Technology, Inc.
//	All rights reserved.
//
//	$Id: PGPeBiz.h,v 1.18 2004/03/11 16:30:56 ishabtay Exp $

//	This is the public include file for the E-Business Server API.

#include "pgpBase.h"

//	Determine linkage conventions (if they haven't already been
//	determined).

#ifndef	EBIZDLL_PUBDECL

	#ifndef	EBIZDLL_PUBDECL_EXT
		#if	__cplusplus
			#define	EBIZDLL_PUBDECL_EXT	extern "C"
		#else
			#define	EBIZDLL_PUBDECL_EXT	extern
		#endif
	#endif

	#ifndef	EBIZDLL_PUBDECL_DLL
		#if defined(PGP_WIN32)

			#ifdef EBIZDLL_EXPORTS
				#define EBIZDLL_PUBDECL_DLL	__declspec(dllexport)
			#else
				#define EBIZDLL_PUBDECL_DLL	__declspec(dllimport)
			#endif

		#else

			#define EBIZDLL_PUBDECL_DLL

		#endif
	#endif

	#define	EBIZDLL_PUBDECL	EBIZDLL_PUBDECL_EXT EBIZDLL_PUBDECL_DLL

#endif

//	Pointer to an E-Business Server API context.

typedef struct PGPeBizContext	*PGPeBizContextRef;

//	PGPeBizInit
//	-----------
//
//	Allocates & initializes an E-Business Server API context structure.
//
//	Parameters:
//
//		pContext	(out)	A pointer to the newly created structure.
//							This pointer should be used in future calls
//							to the E-Business Server API.
//
//	Return code:
//
//		Zero if successful, nonzero for failure.

EBIZDLL_PUBDECL
PGPInt32
PGPeBizInit			(	PGPeBizContextRef	*pContext	);

//	PGPeBiz
//	-------
//
//	Performs an E-Business Server command.
//
//	Parameters:
//
//		pContext	(in)	A pointer to the context structure, created by
//							PGPeBizInit.
//		args		(in)	A pointer to a null-terminated string containing
//							the E-Business Server command to invoke.
//		stdIn		(in)	A pointer to a buffer holding the input to the
//							command.
//		stdInLen	(in)	An integer denoting the length of the buffer pointed
//							to by stdIn.
//		stdOut		(out)	A pointer to the resulting standard output stream.
//							This buffer must be freed using PGPeBizFree.
//		stdOutLen	(out)	A pointer to an integer containing the length
//							of the stdOut buffer.
//		stdErr		(out)	A pointer to the resulting standard error stream.
//							This buffer must be freed using PGPeBizFree.
//		stdErrLen	(out)	A pointer to an integer containing the length
//							of the stdErr buffer.
//
//	Return code:
//
//		Zero if successful, nonzero for failure.

EBIZDLL_PUBDECL
PGPInt32
PGPeBiz				(	PGPeBizContextRef	pContext,
						const char			*args,
						const PGPByte		*stdIn,
						PGPUInt32			stdInLen,
						PGPByte				**stdOut,
						PGPUInt32			*stdOutLen,
						PGPByte				**stdErr,
						PGPUInt32			*stdErrLen	);

//	PGPeBizFree
//	-----------
//
//	Frees resources obtained by PGPeBiz. This can be either the stdOut
//	or stdErr buffers.
//
//	Parameters:
//
//		pContext	(in)	A pointer to the context structure, created by
//							PGPeBizInit.
//		pData		(in)	A pointer to the buffer to be freed.
//
//	Return code:
//
//		None.

EBIZDLL_PUBDECL
void
PGPeBizFree			(	PGPeBizContextRef	context,
						void				*pData	);

//	PGPeBizErrorString
//	------------------
//
//	Returns a string representation of an error code that was returned
//	by any of the API functions.
//
//	Parameters:
//
//		pContext	(in)	A pointer to the context structure, created by
//							PGPeBizInit.
//		returnCode	(in)	The return code.
//		errorString	(in)	A pointer to a buffer to receive the string.
//		maxLen		(in)	The size of the buffer pointed to by errorString.
//
//	Return code:
//
//		A pointer to errorString if successful, NULL for failure.

EBIZDLL_PUBDECL
const char*
PGPeBizErrorString	(	PGPeBizContextRef	context,
						PGPError			returnCode,
						char				*errorString,
						size_t				maxLen	);

//	PGPeBizCleanUp
//	--------------
//
//	Cleans-up the API context structure.
//
//	Parameters:
//
//		pContext	(in)	A pointer to the context structure, created by
//							PGPeBizInit.
//
//	Return code:
//
//		Zero if successful, nonzero on failure.

EBIZDLL_PUBDECL
PGPInt32
PGPeBizCleanUp		(	PGPeBizContextRef	context	);

#endif
