#!/bin/sh

#
# McAfee E-Business Server Installation Script
#

# NOTE: Don't use platform-specific settings here.
#		All per-platform settings should be set in platform.sh.

echo

. ./platform.sh

if [ ! "$WHOAMI" = "" ]; then
	USERNAME=`$WHOAMI`
	if [ ! "$USERNAME" = "root" ]; then
		$ECHO
		$ECHO "This package must be installed by root in order to properly set "
		$ECHO "up the system for multi-user or multi-process use.  It will "
		$ECHO "install system libraries, the EBS SDK Daemon, header files and "
		$ECHO "the executables for use by all users of the system."
		$ECHO
		$ECHO "To use E-Business Server without performing a full installation, "
		$ECHO "use the following steps:"
		$ECHO
		if [ "$PGPSDKD" = "Y" ]; then
			$ECHO " - Do not attempt to use ebscache or ebssdkd, as they are"
			$ECHO "   intended ONLY for use in a multi-processing, multi-user"
			$ECHO "   environment.  If you require concurrency with McAfee"
			$ECHO "   E-Business Server, you must install as root."
			$ECHO
		fi
		if [ "$USE_LIB_ENV" = "Y" ]; then
			$ECHO " - update your $LIB_ENV environment variable to include"
			$ECHO "   the lib/ directory."
			$ECHO
		fi
		$ECHO " - For building software using the e-Business API, ensure that"
		$ECHO "   the lib/ and include/ directories are being used by your"
		$ECHO "   compiler/linker."
		$ECHO
		$ECHO " - Ensure that the ebs binary is in a directory in your PATH."
		$ECHO
		$ECHO " - You may wish to use pgp-default.cfg as the basis for your"
		$ECHO "   pgp.cfg, usually found in \$HOME/.pgp/."
		$ECHO
		$ECHO "Installation cancelled."
		exit 1
	fi
fi

# Dependency checking
#if [ "$OS" = "Linux" ]; then
#fi

# Make directories if they don't already exist.
MADE_DIRS=0
for A_DIR in /usr/local /usr/local/ebs; do {
	if [ ! -d $A_DIR ]; then
		$ECHO "Creating directory $A_DIR: \c";
		mkdir $A_DIR && $ECHO ok
		MADE_DIRS=1;
	fi
} done
if [ "$MADE_DIRS" = "1" ]; then
	# output a blank line if any directories were made.
	$ECHO
fi

# Silently make some other directories
for A_DIR in /usr/local/ebs/uninstall $MK_OTHER_DIRS; do {
	if [ ! -d $A_DIR ]; then
		mkdir $A_DIR 
	fi
} done

$ECHO "Copying binaries to /usr/local/ebs and symlinking to $BINDIR"

$ECHO " - ebs: copying, \c"
( cp ebs /usr/local/ebs && $ECHO "symlinking, \c" && ln -sf /usr/local/ebs/ebs $BINDIR && $ECHO ok ) || ERROR=1;

$ECHO " - ebsreader: copying, \c"
( cp ebsreader /usr/local/ebs && $ECHO "symlinking, \c" && ln -sf /usr/local/ebs/ebsreader $BINDIR && $ECHO ok ) || ERROR=1;

$ECHO " - ebsadmin: copying, \c"
( cp ebsadmin /usr/local/ebs && $ECHO "symlinking, \c" && ln -sf /usr/local/ebs/ebsadmin $BINDIR && $ECHO ok ) || ERROR=1;

$ECHO " - McAfeeEBS.jar (E-Business Server Java API): copying, \c"
( cp McAfeeEBS.jar /usr/local/ebs && $ECHO ok ) || ERROR=1;
$ECHO " - commons-codec-1.2.jar (E-Business Server Java API): copying, \c"
( cp commons-codec-1.2.jar /usr/local/ebs && $ECHO ok ) || ERROR=1;
$ECHO " - McAfeeEBSGUI.jar (E-Business Server Administration Console): copying, \c"
( cp McAfeeEBSGUI.jar /usr/local/ebs && $ECHO ok ) || ERROR=1;

if [ "$PGPSDKD" = "Y" ]; then
	$ECHO " - ebscache: copying, \c"
	( cp ebscache /usr/local/ebs && $ECHO "symlinking, \c" && ln -sf /usr/local/ebs/ebscache $BINDIR && $ECHO ok ) || ERROR=1
fi
$ECHO "...done."
$ECHO

$ECHO "Copying license file to /usr/local/ebs"
$ECHO " - EBusSvr.lic: copying, \c"
( cp EBusSvr.lic /usr/local/ebs && $ECHO ok ) || ERROR=1;
$ECHO

# Need to call this on AIX
$SLIBCLEAN
#
$ECHO "Copying libs to /usr/local/ebs/lib: \c"
if [ ! -d /usr/local/ebs/lib ] ; then
	$MKDIR /usr/local/ebs/lib && $ECHO Created directory /usr/local/ebs/lib;
fi
LNERROR=0
if [ -d /usr/local/ebs/lib ] ; then
	NOW=`pwd`
	cd lib
	ln -sf libxerces-c.$SOEXT.25.0 libxerces-c.$SOEXT.25
	ln -sf libxerces-c.$SOEXT.25 libxerces-c.$SOEXT
	for a in *; do {
		if [ $IS_SYMLINK $a ]; then
			content=`ls -l $a | $GREP "\->" | cut -d \> -f2`
			cd /usr/local/ebs/lib
			ln -sf $content $a || LNERROR=1
			cd $NOW/lib
		else
			cp $a /usr/local/ebs/lib || LNERROR=1
		fi
	} done 
	cd $NOW
else
	LNERROR=1
fi
if [ "$LNERROR" = "1" ]; then
	ERROR=1
else
	$ECHO ok
fi

$ECHO "Copying documentation to /usr/local/ebs/docs: \c"
( cp -R docs /usr/local/ebs && $ECHO ok ) || ERROR=1

$ECHO "Copying man pages to /usr/local/ebs/man: \c"
( cp -R man/ /usr/local/ebs && $ECHO ok ) || ERROR=1

$ECHO "Symlinking ebs.1 to $MANPATH: \c"
( ln -sf /usr/local/ebs/man/man1/ebs.1 $MANPATH/man1/ && echo ok ) || ERROR=1

$ECHO

$ECHO "Copying configuration files to /usr/local/ebs..."
$ECHO " - pgp-default.cfg: \c"
if [ -f /usr/local/ebs/pgp-default.cfg -a "$1" != "-f" ]; then
	if( yes_no "already exists.  Overwrite?" "n" ); then
		( cat pgp-default.cfg | $GREP -vi "^alias" | $GREP -v "^#\^" >> /usr/local/ebs/pgp-default.cfg && $ECHO ok ) || ERROR=1
	fi
elif [ -f /usr/local/ebs/pgp-default.cfg -a "$1" = "-f" ]; then
	#already exists; skipped
	sleep 1
else
	( cat pgp-default.cfg | $GREP -vi "^alias" | $GREP -v "^#\^" >> /usr/local/ebs/pgp-default.cfg && $ECHO ok ) || ERROR=1
fi

$ECHO " - pgp-template.cfg: \c"
if [ -f /usr/local/ebs/pgp-template.cfg ]; then
	$ECHO "already exists; skipped"
	sleep 1
else
	$ECHO "# This file is a default template for the first time a" >> /usr/local/ebs/pgp-template.cfg
	$ECHO "# time a user runs 'ebs'.  At that time, it is copied to the" >> /usr/local/ebs/pgp-template.cfg
	$ECHO "# user's ~/.pgp folder as pgp.cfg." >> /usr/local/ebs/pgp-template.cfg
	$ECHO "# " >> /usr/local/ebs/pgp-template.cfg
	( cat pgp-default.cfg >> /usr/local/ebs/pgp-template.cfg && $ECHO ok ) || ERROR=1
	$ECHO "   -------------"
	$ECHO "   Note: If you have an existing user-template config file with settings you"
	$ECHO "   wish to migrate, add those settings to /usr/local/ebs/pgp-template.cfg."
	$ECHO "   -------------"
	sleep 3
fi

$ECHO " - pgp-policy.cfg: \c"

if [ -f /usr/local/ebs/pgp-policy.cfg ]; then
	$ECHO "already exists; skipped"
	sleep 1
else
	$ECHO "# This is E-Business Server's system policy configuration file. " >> /usr/local/ebs/pgp-policy.cfg
	$ECHO "# It is processed AFTER all command-line options and other configuration" >> /usr/local/ebs/pgp-policy.cfg
	$ECHO "# files, and can be used to enforce a system policy for all users." >> /usr/local/ebs/pgp-policy.cfg
	$ECHO "# " >> /usr/local/ebs/pgp-policy.cfg
	$ECHO "# Note that PUBRING and SECRING, DEFAULT-KEY and RANDSEED cannot be " >> /usr/local/ebs/pgp-policy.cfg
	$ECHO "# overridden in the policy file." >> /usr/local/ebs/pgp-policy.cfg
	$ECHO "#" >> /usr/local/ebs/pgp-policy.cfg
	if [ -f /etc/ebs/pgp.cfg ]; then
		if ( $GREP -v '^[\t ]*#' /etc/ebs/pgp.cfg | $GREP -v '^[\t ]*$' > /dev/null ) ; then
			$ECHO "Detected existing policy configuration file /etc/ebs/pgp.cfg."
			$GREP -v '^[\t ]*#' /etc/ebs/pgp.cfg | $GREP -v '^[\t ]*$' | awk '{print "\t" $0}'
			if [ "$1" != "-f" ]; then
				if ( yes_no "   Do you wish to migrate your previous policy file?" "y" ); then
					$ECHO " - porting settings from /etc/ebs/pgp.cfg...\c"
					$ECHO "# " >> /usr/local/ebs/pgp-policy.cfg
					$ECHO "# The following settings were ported from /etc/ebs/pgp.cfg by the installer: " >> /usr/local/ebs/pgp-policy.cfg
					$ECHO " " >> /usr/local/ebs/pgp-policy.cfg
					$GREP -v '^[\t ]*#' /etc/ebs/pgp.cfg | $GREP -v '^[\t ]*$' >> /usr/local/ebs/pgp-policy.cfg
					$ECHO "# End of settings ported from /etc/ebs/pgp.cfg " >> /usr/local/ebs/pgp-policy.cfg
					$ECHO "# " >> /usr/local/ebs/pgp-policy.cfg
					$ECHO  >> /usr/local/ebs/pgp-policy.cfg
					$ECHO  >> /usr/local/ebs/pgp-policy.cfg
				fi
			else
				$ECHO " - porting settings from /etc/ebs/pgp.cfg...\c"
				$ECHO "# " >> /usr/local/ebs/pgp-policy.cfg
				$ECHO "# The following settings were ported from /etc/ebs/pgp.cfg by the installer: " >> /usr/local/ebs/pgp-policy.cfg
				$ECHO " " >> /usr/local/ebs/pgp-policy.cfg
				$GREP -v '^[\t ]*#' /etc/ebs/pgp.cfg | $GREP -v '^[\t ]*$' >> /usr/local/ebs/pgp-policy.cfg
				$ECHO "# End of settings ported from /etc/ebs/pgp.cfg " >> /usr/local/ebs/pgp-policy.cfg
				$ECHO "# " >> /usr/local/ebs/pgp-policy.cfg
				$ECHO  >> /usr/local/ebs/pgp-policy.cfg
				$ECHO  >> /usr/local/ebs/pgp-policy.cfg
			fi
		fi
	fi
	( cat pgp-default.cfg | $GREP -vi "^alias" | $GREP -v "^#\^" >> /usr/local/ebs/pgp-policy.cfg && $ECHO ok ) || ERROR=1
fi
$ECHO "...done."

$ECHO

$ECHO "Copying additional information files to /usr/local/ebs..."
#( $ECHO " - Sample keys: \c" && cp keyrings/SampleKeys.asc /usr/local/ebs && $ECHO ok ) || ERROR=1
( $ECHO " - LICENSE: \c" && cp LICENSE /usr/local/ebs && $ECHO ok ) || ERROR=1
$ECHO "...done."

$ECHO
sleep 1

$ECHO "Symlinking /usr/local/ebs/lib to /usr/lib/ebs: \c"

# barf out if /usr/lib/ebs is a directory
if [ -d /usr/lib/ebs -a ! $IS_SYMLINK /usr/lib/ebs ]; then
	$ECHO "Error!"
	$ECHO "The /usr/lib/ebs directory must not exist for a successful"
	$ECHO "installation of E-Business Server.  /usr/local/ebs/lib needs to be symlinked there."
	exit 1
fi

( ln -sf /usr/local/ebs/lib /usr/lib/ebs && $ECHO ok ) || ERROR=1

$ECHO
if [ -f /etc/ld.so.conf ]; then
	if ! $GREP "/usr/lib/ebs" /etc/ld.so.conf > /dev/null ; then
		$ECHO "Adding /usr/lib/ebs to /etc/ld.so.conf \c"
		$ECHO /usr/lib/ebs >> /etc/ld.so.conf
		$ECHO "...and updating /etc/ld.so.cache:"
		ldconfig -v | $GREP -i "ebs"
		$ECHO
	fi
fi


# copy header files to /usr/local/ebs/include for e-biz API:
$ECHO "Copying header files to include directory /usr/local/ebs/include: \c"
( cp -R include /usr/local/ebs && echo ok ) || ERROR=1

$ECHO

# copy sample files to /usr/local/ebs/include for e-biz API:
$ECHO "Copying sample code to /usr/local/ebs/samples: \c"
( cp -R samples /usr/local/ebs && echo ok ) || ERROR=1

$ECHO

$ECHO "Adding $BINDIR/pgp link for script compatibility: \c"

if [ -f $BINDIR/pgp ]; then
	$ECHO "$BINDIR/pgp already exists"
else
	( ln -sf /usr/local/ebs/ebs $BINDIR/pgp && $ECHO ok ) || ERROR=1
fi

$ECHO

$ECHO "Copying uninstall information to /usr/local/ebs/uninstall: \c"
( cp uninstall.sh platform.sh /usr/local/ebs/uninstall/ && $ECHO ok ) || ERROR=1

# Create local sbin if necessary
if [ ! -d /usr/local/sbin ]; then
	$MKDIR /usr/local/sbin && $ECHO Created directory /usr/local/sbin;
fi

# Set up EBS's required environment variables in a secured file
$ECHO EBSDIR=/usr/local/ebs >> /usr/local/sbin/EBSVARS
$ECHO export EBSDIR >> /usr/local/sbin/EBSVARS
$ECHO $LIBENV=\$$LIBENV:/usr/lib:/usr/local/lib:/usr/lib/ebs:/usr/local/ebs/lib >> /usr/local/sbin/EBSVARS
$ECHO export $LIBENV >> /usr/local/sbin/EBSVARS
if [ "$LIBENV2" != "" ]; then
	$ECHO export $LIBENV2=\$$LIBENV2:/usr/lib:/usr/local/lib:/usr/lib/ebs:/usr/local/ebs/lib >> /usr/local/sbin/EBSVARS
fi
chmod 755 /usr/local/sbin/EBSVARS
$ECHO . /usr/local/sbin/EBSVARS >> /etc/profile


# The PGPsdkd daemon isn't present on all systems
if [ "$PGPSDKD" = "Y" ]; then
	$ECHO "Installing the SDK daemon (ebssdkd) into /usr/local/sbin"
	cp -p ebssdkd /usr/local/sbin/ebssdkd
	if [ $? != 0 ]; then ERROR=1; fi
	$ECHO "Installing the startup script (S10pgpsdkd) into $INITDIR/ebssdkd"
	cp -p S10pgpsdkd "$INITDIR/ebssdkd"
	if [ $? != 0 ]; then ERROR=1; fi
	if [ -f "$INITDIR/ebssdkd" ]; then
		chmod +x "$INITDIR/ebssdkd"
		if [ $? != 0 ]; then ERROR=1; fi
		ln -sf "$INITDIR/ebssdkd" "$STARTUPDIR/S10pgpsdkd"
		if [ $? != 0 ]; then ERROR=1; fi
	fi
	$ECHO

	$ECHO "The SDK daemon will automatically start at next boot."
	
	if [ "$1" != "-f" ]; then
		if (yes_no "Would you like to start the SDK daemon now?" "Y"); then
			$INITDIR/ebssdkd start
			if [ $? != 0 ]; then ERROR=1; fi
		else 
			$ECHO
			$ECHO "To start the EBS SDK manually, run:"
			$ECHO "  $INITDIR/ebssdkd start"
		fi
	else
		$INITDIR/ebssdkd start
		if [ $? != 0 ]; then ERROR=1; fi
	fi
	$ECHO
fi

# Add ebsadmin daemon
$ECHO "Installing the client admin daemon (ebsadmin) into /usr/local/sbin"
cp -p ebsadmin /usr/local/sbin/ebsadmin
if [ $? != 0 ]; then ERROR=1; fi


PGP_LOCATION=`which ebs`;
if ( echo "$PGP_LOCATION" | $GREP "^no ebs in " > /dev/null ); then
	# HPUX sticks the error message on stdout :~(  so we'll make it
	# appear correctly there.
	$ECHO "which: $PGP_LOCATION"
	PGP_LOCATION="";
fi

if [ "$PGP_LOCATION" = "" ]; then
	$ECHO
	$ECHO "WARNING: You need to add $BINDIR to your PATH, and your users"
	$ECHO "         may also need to do so, in order to run EBS.  Alternatively,"
	$ECHO "         you may wish to symlink $BINDIR/ebs into a directory"
	$ECHO "         that will be found in your users' PATH."
	$ECHO
	ERROR=1
	sleep 2
else
	if [ ! "$PGP_LOCATION" = "$BINDIR/ebs" ]; then
		$ECHO "WARNING: 'which ebs' reports that you will be executing"
		$ECHO "         $PGP_LOCATION instead of $BINDIR/ebs. " 
		$ECHO "         You should verify that this is the correct EBS you wish to"
		$ECHO "         run.  You may also wish to check your users' PATH to ensure"
		$ECHO "         they'll be running the correct EBS."
		$ECHO
		ERROR=1
		sleep 2
	fi
fi

$ECHO "To remove E-Business Server, run the uninstall script in /usr/local/ebs/uninstall/."
$ECHO

if [ "$ERROR" = "1" ]; then
	$ECHO "One or more errors have been detected.  Please review the messages above"
	$ECHO "to ensure that installation has completed successfully."

	exit 1
else
	$ECHO "Installation successful."
fi
