/*
 * Copyright (C) 2001 Networks Associates Technology, Inc.
 * All rights reserved.
 *
 * $Id: APISample.c,v 1.4 2004/01/08 15:46:37 ishabtay Exp $
 *
 * This is an example program that demonstrates the PGP E-Business API
 * in a single-threaded application.
 *
 */

#include <stdio.h>
#include <stdlib.h>

#include "PGPeBiz.h" /* API header, must be included in all API programs */

#define STR_LEN 1024 /* generic length for tmp strings */

/* Win32 specific stuff */
#ifdef PGP_WIN32
#define snprintf _snprintf
#endif /* win32 */

int main(int argc, char *argv[])
 {
    int returnValue;		            /* PGPeBiz() return value */
    char commandString[STR_LEN + 1];	/* buffer for commands */
    PGPByte *stdoutBuffer;              /* buffers for I/O */
    PGPByte *stderrBuffer;
    PGPByte stdinBuffer[STR_LEN + 1];	
    PGPUInt32 stdoutLen;                /* length of I/O buffers */
    PGPUInt32 stderrLen;
    PGPUInt32  stdinLen;	
    char errorString[STR_LEN + 1];      /* buffer to store error descriptions */
    int anykey;			                /* tmp character */
    int status;			                /* tmp variable for function status */
    PGPeBizContextRef context;	        /* must be used in API calls */

    /* This function must be called before any other API calls.
     * You must save the "context" for future API calls.
     */
    status = PGPeBizInit(&context);
    if (status != 0) {
      fprintf(stderr, "Could not initialize context\n");
      exit(1);
    }


    /* example that lists the keyring */

    snprintf(commandString, STR_LEN,
        "--key-list"); /* stuff command string */

    returnValue = PGPeBiz(context,	    /* eBiz context */
			  commandString,    /* the command line */
			  NULL,	            /* we have no stdin */
			  0,	            /* stdin has no length */
			  &stdoutBuffer,    /* stdout buffer, caller must free */
			  &stdoutLen,	    /* stdout buffer length */
			  &stderrBuffer,    /* stderr buffer, caller must free */
			  &stderrLen);	    /* stderr length */

	printf("Command is [%s]\n", commandString);
	
	if (stdoutLen != 0)
	  printf("stdout = [%.*s] = %d bytes\n", (int) stdoutLen, stdoutBuffer,
			 stdoutLen);
	else
	  printf("stdout is empty\n");
	
	if (stderrLen != 0)
	  printf("stderr = [%.*s] = %d bytes\n", (int) stderrLen, stderrBuffer,
			 stderrLen);
	else
	  printf("stderr is empty\n");

    printf("PGPeBiz() returned a code of %d which is %s\n", returnValue,
	   PGPeBizErrorString(context, returnValue, errorString, STR_LEN));

    /* the caller MUST free these buffers when done with them */
    PGPeBizFree(context, stdoutBuffer);
    PGPeBizFree(context, stderrBuffer);

    printf("\nHit <RETURN> to continue\n");
    anykey = getchar();

    /* this will encrypt the stdin buffer to a file called test.txt.pgp */

    snprintf(commandString, STR_LEN,

	  "--encrypt --conventional --conventional-passphrase \"test this\" "
	  "--overwrite "
	  "--output test.txt.pgp");	/* stuff command string */

    stdinLen = snprintf(stdinBuffer, STR_LEN,
			    "This is a test\nThis is only a test.\nThank you for "
    			"your support.\n");	/* data to be encrypted */

    returnValue = PGPeBiz(context,          /* eBiz context */
			  commandString,    /* the command line */
			  stdinBuffer,	    /* stdin */
			  stdinLen,	    /* stdin length */
			  &stdoutBuffer,    /* stdout buffer, caller must free */
			  &stdoutLen,	    /* stdout buffer length */
			  &stderrBuffer,    /* stderr buffer, caller must free */
			  &stderrLen);	    /* stderr length */

	printf("Command is [%s]\n", commandString);
	
	if (stdoutLen != 0)
	  printf("stdout = [%.*s] = %d bytes\n", (int) stdoutLen, stdoutBuffer,
			 stdoutLen);
	else
	  printf("stdout is empty\n");
	
	if (stderrLen != 0)
	  printf("stderr = [%.*s] = %d bytes\n", (int) stderrLen, stderrBuffer,
			 stderrLen);
	else
	  printf("stderr is empty\n");

	printf("PGPeBiz() returned a code of %d which is %s\n", returnValue,
	   PGPeBizErrorString(context, returnValue, errorString, STR_LEN));

    /* the caller MUST free these buffers when done with them */
    PGPeBizFree(context, stdoutBuffer);
    PGPeBizFree(context, stderrBuffer);

    printf("\nHit <RETURN> to continue\n");
    anykey = getchar();

    /* this will decrypt a file */
    snprintf(commandString, STR_LEN,
	     "--decrypt test.txt.pgp --passphrase \"test this\" --output -");

    returnValue = PGPeBiz(context,          /* eBiz context */
			  commandString,    /* the command line */
			  NULL,	            /* we have no stdin */
			  0,	            /* stdin has no length */
			  &stdoutBuffer,    /* stdout buffer, caller must free */
			  &stdoutLen,	    /* stdout buffer length */
			  &stderrBuffer,    /* stderr buffer, caller must free */
			  &stderrLen);	    /* stderr length */

	printf("Command is [%s]\n", commandString);

	if (stdoutLen != 0)
	  printf("stdout = [%.*s] = %d bytes\n", (int) stdoutLen, stdoutBuffer,
			 stdoutLen);
	else
	  printf("stdout is empty\n");
	
	if (stderrLen != 0)
	  printf("stderr = [%.*s] = %d bytes\n", (int) stderrLen, stderrBuffer,
			 stderrLen);
	else
	  printf("stderr is empty\n");

    printf("PGPeBiz() returned a code of %d which is %s\n", returnValue,
	   PGPeBizErrorString(context, returnValue, errorString, STR_LEN));

    /* the caller MUST free these buffers when done with them */
    PGPeBizFree(context, stdoutBuffer);
    PGPeBizFree(context, stderrBuffer);

    printf("\nHit <RETURN> to finish\n");
    anykey = getchar();

    /* This should be called last to free up the eBiz context.
     * If you want to make any more API calls after freeing the
     * context, you must call PGPeBizInit() to create a new context
     * first.
     */
    PGPeBizCleanUp(context);
    return (0);
} /* main */

/*__Editor_settings____

    Local Variables:
    tab-width: 4
    End:
    vi: ts=4 sw=4
    vim: si
_____________________*/
