/* $Id: EBizSample.java,v 1.3 2004/03/02 01:50:02 ishabtay Exp $ */

/**
 * EBizSample is Java class which demonstrates how to use the
 * E-Business Server Java API (PGPjava).
 * @author Isaac Shabtay  &lt;<a href="mailto:isaac_shabtay@nai.com">isaac_shabtay@nai.com</a>&gt;
 */

import java.io.InputStreamReader;
import java.io.BufferedReader;
import java.io.IOException;

import com.mcafee.ebs.EBiz;

public class EBizSample
{
	/**
	 * Sample code showing how to use the EBiz object.
	 * @param args Command line arguments (unused).
	 */

	public static void main (String[] args)
	{
		System.err.println("This sample program will demonstrate the abilities of the");
		System.err.println("E-Business Server Java API (PGPjava).");

		EBiz e = new EBiz ();

		String	choice;
		char	cChoice;

		String	cmd = null;		// Command to run

		BufferedReader br = new BufferedReader(new InputStreamReader(System.in));

		//	Go forever

		while (true)
		{
			//	Display menu

			System.err.println();
			System.err.println("Please select one of the following options:");
			System.err.println();
			System.err.println("1) Show version info (--version)");
			System.err.println("2) Show key list     (--key-list)");
			System.err.println("3) Encrypt a string  (--encrypt --armor --conventional)");
			System.err.println();
			System.err.println("9) Quit");
			System.err.println();

			//	Get choice

			try
			{
				choice = br.readLine();
			}
			catch (IOException ex)
			{
				break;
			}

			//	Syntax check

			if (choice == null || choice.length() != 1)
			{
				System.err.println("Invalid choice");
				continue;
			}

			//	Get choice

			cChoice = choice.charAt(0);

			if (cChoice == '9')
				break;

			//	What did he want?

			switch(cChoice)
			{
				case '1':
					cmd = "--version";
					break;

				case '2':
					cmd = "--key-list";
					break;

				case '3':
					cmd = "--encrypt --armor --conventional --conventional-passphrase foobar";

					//	Get string to encrypt

					System.err.println("Please type a string to encrypt:");
					System.err.println();

					String	stringToEncrypt = null;

					try
					{
						stringToEncrypt = br.readLine();
					}
					catch (IOException ex)
					{
						continue;
					}

					//	Null string is an empty string for us.

					if (stringToEncrypt == null)
						stringToEncrypt = "";

					e.stdin(stringToEncrypt);

					break;

				default:

					//	Invalid choice

					System.err.println("Invalid choice");
					System.err.println();

					break;
			}

			//	Run command

			boolean	success = e.run(cmd);

			//	Print stdout and stderr, if any.

			if (e.stdout() != null)
			{
				System.err.println("stdout follows:");
				System.err.println("---------------");
				System.err.println();
				System.err.println(new String(e.stdout()));
			}
			else
			{
				System.err.println("no stdout for this command");
			}

			if (e.stderr() != null)
			{
				System.err.println("stderr follows:");
				System.err.println("---------------");
				System.err.println();
				System.err.println(e.stderr());
			}
			else
			{
				System.err.println("no stderr for this command");
			}

			//	Conclusion.

			if (success)
				System.err.println("Command succeeded.");
			else
				System.err.println("Command failed. Error string is: " + e.error_string());
		}
	}
}
