/*____________________________________________________________________________
Copyright (C) 2000 Networks Associates Technology, Inc.
All rights reserved.

$Id: FrmEncryption.java,v 1.1 2003/10/27 23:46:19 ishabtay Exp $
____________________________________________________________________________*/

/************************************************************
 *
 * Filename:		FrmEncryption.java
 *
 * Author:		Alex Faieta
 * Date:		September 7, 2001
 * Editor:		Notepad
 * Java Version:	Sun Java 1.3.1
 * Description:
 *
 ************************************************************/

// Sun Java packages
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.BorderLayout;
import java.awt.Container;
import java.awt.GridLayout;
import java.io.File;
import javax.swing.AbstractButton;
import javax.swing.JButton;
import javax.swing.JFileChooser;
import javax.swing.JInternalFrame;
import javax.swing.JOptionPane;
import javax.swing.JPanel;

// PGPeBizJava packages
import com.mcafee.ebs.EBiz;


public class FrmEncryption extends JInternalFrame
{
	private PGPEncryption	m_encrypt	= null;
	private Util		m_util		= null;
	private int		m_RunMode	= 0;
	private final int	C_ENCRYPT_DIR	= 0;
	private final int	C_ENCRYPTED_DIR	= 1;
	private final int	C_DECRYPTED_DIR	= 2;


	/**
	 * Ctor setup
	 */
	public FrmEncryption( String frmCaption, EBiz ebiz, int runMode )
	{
		super( frmCaption, false, true, false, true );

		// set the style of the frame
		setSize( 300, 60 );
		setDefaultCloseOperation( DISPOSE_ON_CLOSE );
		getContentPane().setLayout( new BorderLayout() );

		m_RunMode = runMode;
		_addCommandPanel();

		m_encrypt = new PGPEncryption( ebiz );
		m_util = new Util();

		show();
	}

	/**
	 * Add the command button panel at the bottom of this form
	 */
	private void _addCommandPanel()
	{
		final int C_ROW_COUNT = 1;
		final int C_COLUMN_COUNT = 3;

		JPanel _pnlCmdButton = new JPanel( new GridLayout( C_ROW_COUNT, C_COLUMN_COUNT ) );
		getContentPane().add( _pnlCmdButton, BorderLayout.SOUTH );


		/* determine which command button to add based on run-time mode		*/
		switch( m_RunMode )
		{
		case PGPeBizJava_RunMode.ENCRYPT_FILE:
			_addButtonSelection( _pnlCmdButton,
				new JButton( PGPeBizJava_Prompts.ENCR_ENCRYPT_FILES_MSG ), PGPeBizJava_RunMode.ENCRYPT_FILE );
			break;

		case PGPeBizJava_RunMode.DECRYPT_FILE:
			_addButtonSelection( _pnlCmdButton,
				new JButton( PGPeBizJava_Prompts.ENCR_DECRYPT_FILES_MSG ), PGPeBizJava_RunMode.DECRYPT_FILE );
			break;

		case PGPeBizJava_RunMode.COMPARE_FILES:
			_addButtonSelection( _pnlCmdButton,
				new JButton( PGPeBizJava_Prompts.ENCR_COMPARE_FILES_MSG ), PGPeBizJava_RunMode.COMPARE_FILES );
			break;

		case PGPeBizJava_RunMode.WIPE_FILES:
			_addButtonSelection( _pnlCmdButton,
				new JButton( PGPeBizJava_Prompts.ENCR_WIPE_FILES_MSG ), PGPeBizJava_RunMode.WIPE_FILES );
			break;
		}


		_addButtonSelection( _pnlCmdButton,
				new JButton( PGPeBizJava_Prompts.COMMON_CANCEL_MSG ), PGPeBizJava_RunMode.CANCEL_OPTION );
	}


	/**
	 * Add individual buttons to a panel
	 */
	private void _addButtonSelection( Container _ctn, AbstractButton _btn, final int _btnType )
	{
		_btn.addActionListener( new ActionListener() {
			public void actionPerformed( ActionEvent e ) {
				switch( _btnType )
				{
				case PGPeBizJava_RunMode.ENCRYPT_FILE:
					_displayEncrypt();
					break;
				case PGPeBizJava_RunMode.DECRYPT_FILE:
					_displayDecrypt();
					break;
				case PGPeBizJava_RunMode.COMPARE_FILES:
					_compareFiles();
					break;
				case PGPeBizJava_RunMode.WIPE_FILES:
					_wipeFiles();
					break;
				case PGPeBizJava_RunMode.CANCEL_OPTION:
					dispose();
					break;
				};
			}
		} );
		_ctn.add( _btn );
	}

	/**
	 * Wipe multiple files selected, display prompt if
	 * successful/unsuccessful per file.
	 */
	private void _wipeFiles()
	{
		File[] _files = m_util.selectFiles();

		for( int idx=0; idx < _files.length; idx++ )
		{
			if(  m_encrypt.wipeFile( _files[ idx ] )  )
				JOptionPane.showMessageDialog( null, PGPeBizJava_Prompts.ENCR_WIPE_SUCCESS_MSG );
			else
				JOptionPane.showMessageDialog( null, PGPeBizJava_Prompts.ENCR_WIPE_UNSUCCESS_MSG + "\n" +
						_files[ idx ].getPath() );
		}

	}

	/**
	 * Encrypt multiple files selected, display prompt if
	 * successful/unsuccessful per file.
	 */
	private void _displayEncrypt()
	{
		File[] _files = m_util.selectFiles(
					m_util.getCurrentDir().concat( PGPeBizJava_RunMode.m_dirPaths[ C_ENCRYPT_DIR ] )
				);

		for( int idx=0; idx < _files.length; idx++ )
		{
			String _newFile = PGPeBizJava_RunMode.m_dirPaths[ C_ENCRYPTED_DIR ];
			if(  m_encrypt.encrypt( _files[idx], _newFile )  )
				JOptionPane.showMessageDialog( null, PGPeBizJava_Prompts.ENCR_ENCRYPT_SUCCESS_MSG + "\n" + _newFile );
			else
				JOptionPane.showMessageDialog( null, PGPeBizJava_Prompts.ENCR_ENCRYPT_UNSUCCESS_MSG + "\n" +
						_files[ idx ].getPath() );
		}
	}


	/**
	 * Decrypt multiple files selected, display prompt if
	 * successful/unsuccessful per file.
	 */
	private void _displayDecrypt()
	{
		File[] _files = m_util.selectFiles(
					m_util.getCurrentDir().concat( PGPeBizJava_RunMode.m_dirPaths[ C_ENCRYPTED_DIR ] )
				);

		for( int idx=0; idx < _files.length; idx++ )
		{
			String _newFile = PGPeBizJava_RunMode.m_dirPaths[ C_DECRYPTED_DIR ];
			if(  m_encrypt.decrypt( _files[idx], _newFile )  )
				JOptionPane.showMessageDialog( null, PGPeBizJava_Prompts.ENCR_DECRYPT_SUCCESS_MSG + "\n" + _newFile );
			else
				JOptionPane.showMessageDialog( null, PGPeBizJava_Prompts.ENCR_DECRYPT_UNSUCCESS_MSG + "\n" +
						_files[ idx ].getPath() );
		}
	}

	/**
	 * Compares multiple files in the order of selection.
	 * Display prompt if comparison successful/unsuccessful per file.
	 */
	private void _compareFiles()
	{
		File[] _originalFiles = m_util.selectFiles( PGPeBizJava_RunMode.m_dirPaths[ C_ENCRYPT_DIR ] );
		if( _originalFiles.length <= 0 )
			return;

		File[] _decryptedFiles = m_util.selectFiles( PGPeBizJava_RunMode.m_dirPaths[ C_DECRYPTED_DIR ] );
		if( _decryptedFiles.length <= 0 )
			return;

		for( int idx=0; idx < _originalFiles.length || idx < _decryptedFiles.length; idx++ )
		{
			if(  m_encrypt.isCompareValid(	_originalFiles[ idx ],
							_decryptedFiles[ idx ]  )	)
				JOptionPane.showMessageDialog( null, PGPeBizJava_Prompts.ENCR_COMPARE_SUCCESS_MSG );
			else
				JOptionPane.showMessageDialog( null, PGPeBizJava_Prompts.ENCR_COMPARE_UNSUCCESS_MSG + "\n" +
						_originalFiles[ idx ].getPath() + "\n" +
						_decryptedFiles[ idx ].getPath() );
		}
	}
}
