/*____________________________________________________________________________
Copyright (C) 2000 Networks Associates Technology, Inc.
All rights reserved.

$Id: FrmHelpCommands.java,v 1.1 2003/10/27 23:46:19 ishabtay Exp $
____________________________________________________________________________*/

/************************************************************
 *
 * Filename:		FrmHelpCommands.java
 *
 * Author:		Alex Faieta
 * Date:		September 13, 2001
 * Editor:		Notepad
 * Java Version:	Sun Java 1.3.1
 * Description:
 *
 ************************************************************/

// Sun Java packages
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.BorderLayout;
import java.awt.GridLayout;
import java.awt.Container;
import javax.swing.AbstractButton;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JInternalFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;

// PGPeBizJava packages
import com.mcafee.ebs.EBiz;


public class FrmHelpCommands extends JInternalFrame
{
	private JTextArea	m_txtHelpDisplay	= null;
	private JComboBox	m_cboHelpCommands	= null;
	private PGPHelp		m_help			= null;


	/**
	 * Ctor setup
	 */
	public FrmHelpCommands( EBiz biz )
	{
		super( PGPeBizJava_Prompts.FORM_HELP_COMMANDS_CAPTION, false, true, false, true );
		setSize( 500, 400 );
		setOpaque( true );
		setDefaultCloseOperation( DISPOSE_ON_CLOSE );
		getContentPane().setLayout( new BorderLayout() );

		_addCommandPanel();
		_addHelpView();

		m_help = new PGPHelp( biz );

		show();
	}

	/**
	 * Add the command button panel at the bottom of this form
	 */
	private void _addCommandPanel()
	{
		final int C_ROW_COUNT = 1;
		final int C_COLUMN_COUNT = 1;

		JPanel _pnlCmdButton = new JPanel( new GridLayout( C_ROW_COUNT, C_COLUMN_COUNT ) );
		getContentPane().add( _pnlCmdButton, BorderLayout.SOUTH );


		_addButtonSelection( _pnlCmdButton, new JButton( PGPeBizJava_Prompts.COMMON_CANCEL_MSG ), PGPeBizJava_RunMode.CANCEL_OPTION );
	}

	/**
	 * Adds the main view for input/output
	 */
	private void _addHelpView()
	{
		final int C_ROW_COUNT = 4;
		final int C_COLUMN_COUNT = 2;

		JPanel _pnlViews = new JPanel( new BorderLayout( C_ROW_COUNT, C_COLUMN_COUNT ) );
		getContentPane().add( _pnlViews, BorderLayout.NORTH );



		_loadHelpCommands();
		_addComboListener( m_cboHelpCommands, PGPeBizJava_RunMode.HELP_COMMAND );
		_pnlViews.add( new JLabel( PGPeBizJava_Prompts.HELP_SELECT_CMD_MSG ), BorderLayout.NORTH );
		_pnlViews.add( m_cboHelpCommands, BorderLayout.CENTER );

		m_txtHelpDisplay = new JTextArea( 17, 10 );
		m_txtHelpDisplay.setEditable( false );
		JScrollPane _scrHelpDisplay = new JScrollPane( m_txtHelpDisplay );
		_pnlViews.add( _scrHelpDisplay, BorderLayout.SOUTH );
	}

	/**
	 * Add individual buttons to a panel
	 */
	private void _addButtonSelection( Container _ctn, AbstractButton _btn, final int _btnType )
	{
		_btn.addActionListener( new ActionListener() {
			public void actionPerformed( ActionEvent e ) {
				switch( _btnType )
				{
				case PGPeBizJava_RunMode.CANCEL_OPTION:
					dispose();
					break;
				};
			}
		} );
		_ctn.add( _btn );
	}

	/**
	 * Add individual Comboboxes to a panel
	 */
	private void _addComboListener( JComboBox _cbo, final int _btnType )
	{
		_cbo.addActionListener( new ActionListener() {
			public void actionPerformed( ActionEvent e ) {
				switch( _btnType )
				{
				case PGPeBizJava_RunMode.HELP_COMMAND:
					_displayHelp();
					break;
				}
			}
		} );
	}

	/**
	 * Displays the help, based on the selected command
	 */
	private void _displayHelp()
	{
		m_txtHelpDisplay.setText( m_help.getHelp(
			(String) m_cboHelpCommands.getSelectedItem()
		) );
		m_txtHelpDisplay.setCaretPosition( 0 );
	}

	/**
	 * Loads all the help commands into the help combobox
	 */
	private void _loadHelpCommands()
	{
		PGPeBizJava_CmdlineArgs _cmd = new PGPeBizJava_CmdlineArgs();
		String[] _strHelpCommands = {	_cmd.C_LIST_ALIASES_CMDLINE,			_cmd.C_SIGN_CMDLINE,
						_cmd.C_HELP_CMDLINE,				_cmd.C_VERSION_CMDLINE,
						_cmd.C_WIPE_CMDLINE,				_cmd.C_CONVENTIONAL_PASSPHRASE_CMDLINE,		_cmd.C_ENCRYPT_ARMOR_CMDLINE,
						_cmd.C_ENCRYPT_CMDLINE,				_cmd.C_DECRYPT_CMDLINE,
						_cmd.C_KEY_ADD_CMDLINE,				_cmd.C_KEY_DETAIL_CMDLINE,
						_cmd.C_KEY_EDIT_CMDLINE,			_cmd.C_KEY_EXPORT_CMDLINE,
						_cmd.C_KEY_EXTRACT_PHOTOID_CMDLINE,		_cmd.C_KEY_JOIN_CMDLINE,
						_cmd.C_KEY_LIST_CMDLINE,			_cmd.C_KEY_GEN_CMDLINE,
						_cmd.C_KEY_RECONSTRUCT_CMDLINE,			_cmd.C_KEY_RECONSTRUCT_DATA_CMDLINE,
						_cmd.C_KEY_REMOVE_CMDLINE,			_cmd.C_KEY_SEND_SHARE_CMDLINE,
						_cmd.C_KEY_SIG_DETAIL_CMDLINE,			_cmd.C_KEY_SIGN_CMDLINE,
						_cmd.C_KEY_SPLIT_CMDLINE,			_cmd.C_KEY_UPDATE_CMDLINE,
						_cmd.C_KEY_ADD_PHOTOID_CMDLINE,			_cmd.C_KEY_ADD_REVOKER_CMDLINE,
						_cmd.C_KEY_ADD_USERID_CMDLINE,			_cmd.C_KEY_CHANGE_PASSPHRASE_CMDLINE,
						_cmd.C_KEY_DISABLE_CMDLINE,			_cmd.C_KEY_ENABLE_CMDLINE,
						_cmd.C_KEY_REMOVE_PHOTOID_CMDLINE,		_cmd.C_KEY_REMOVE_SIG_CMDLINE,
						_cmd.C_KEY_REMOVE_SUBKEY_CMDLINE,		_cmd.C_KEY_REMOVE_USERID_CMDLINE,
						_cmd.C_KEY_REVOKE_CMDLINE,			_cmd.C_KEY_REVOKE_SIG_CMDLINE,
						_cmd.C_KEY_REVOKE_SUBKEY_CMDLINE,		_cmd.C_KEY_SET_PRIMARY_USERID_CMDLINE,
						_cmd.C_KEY_TRUST_CMDLINE,			_cmd.C_KEY_SERVER_URL_CMDLINE,
						_cmd.C_KEY_SERVER_DELETE_CMDLINE,		_cmd.C_KEY_SERVER_DISABLE_CMDLINE,
						_cmd.C_KEY_SERVER_FETCH_CMDLINE,		_cmd.C_KEY_SERVER_SEARCH_CMDLINE,
						_cmd.C_KEY_SERVER_SEND_CMDLINE,			_cmd.C_GROUP_CMDLINE,
						_cmd.C_GROUP_ADD_CMDLINE,			_cmd.C_GROUP_DETAIL_CMDLINE,
						_cmd.C_GROUP_LIST_CMDLINE,			_cmd.C_GROUP_REMOVE_CMDLINE,
						_cmd.C_GROUPSFILE_CMDLINE,			_cmd.C_SMARTCARD_CMDLINE,
						_cmd.C_SMARTCARD_DLL_CMDLINE,			_cmd.C_SMARTCARD_TYPE_CMDLINE,
						_cmd.C_SMARTCARD_PIN_CMDLINE,			_cmd.C_SMARTCARD_PIND_FD_CMDLINE,
						_cmd.C_ISSUER_DN_CMDLINE,			_cmd.C_ISSUER_SERIAL_CMDLINE,
						_cmd.C_XOP_CERT_CMDLINE,			_cmd.C_XOP_CERT_REQUEST_CMDLINE,
						_cmd.C_XOP_CERT_RETRIEVE_CMDLINE,		_cmd.C_XOP_CERT_NEW_NON_UNIQUE_CMDLINE,
						_cmd.C_XOP_CERT_NEW_UNIQUE_CMDLINE,		_cmd.C_XOP_CERT_NEW_SIG_CMDLINE,
						_cmd.C_XOP_CERT_EXPORT_NON_UNIQUE_CMDLINE,	_cmd.C_XOP_CERT_EXPORT_UNIQUE_CMDLINE,
						_cmd.C_XOP_CERT_EXPORT_ONLY_X_CMDLINE,		_cmd.C_XOP_FETCH_CERT_REVOKE_LIST_CMDLINE,
						_cmd.C_XOP_UPDATE_CMDLINE
					};


		m_cboHelpCommands = new JComboBox( _strHelpCommands );
	}
}
