/*____________________________________________________________________________
Copyright (C) 2000 Networks Associates Technology, Inc.
All rights reserved.

$Id: FrmListKeyInfo.java,v 1.1 2003/10/27 23:46:19 ishabtay Exp $
____________________________________________________________________________*/

/************************************************************
 *
 * Filename:		FrmListKeyInfo.java
 *
 * Author:		Alex Faieta
 * Date:		September 13, 2001
 * Editor:		Notepad
 * Java Version:	Sun Java 1.3.1
 * Description:
 *
 ************************************************************/


// Sun Java packages
import java.awt.BorderLayout;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.GridLayout;
import javax.swing.AbstractButton;
import javax.swing.JButton;
import javax.swing.JInternalFrame;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;

// PGPeBizJava packages
import com.mcafee.ebs.EBiz;


public class FrmListKeyInfo extends JInternalFrame
{
	private PGPKeys		m_keys		= null;
	private String		m_strKeyDetail	= null;
	private String		m_strKeyId	= null;
	private JTextArea	m_txtKeyInfo	= null;
	private JButton		m_cmdDelete	= null;
	private JButton		m_cmdExport	= null;


	/**
	 * Ctor setup
	 */
	public FrmListKeyInfo( EBiz biz )
	{
		super( PGPeBizJava_Prompts.FORM_KEY_INFO_CAPTION, false, true, false, true );
		setSize( 480, 300 );
		setDefaultCloseOperation( DISPOSE_ON_CLOSE );

		m_keys = new PGPKeys( biz );
		m_strKeyId = "0";
		m_cmdDelete = new JButton( PGPeBizJava_Prompts.KEY_DELETE_ID_MSG );
		m_cmdDelete.setEnabled( false );
		m_cmdExport = new JButton( PGPeBizJava_Prompts.KEY_EXPORT_MSG );
		m_cmdExport.setEnabled( false );

		_addCommandPane();
		_addKeyInfoView();

		show();
	}

	/**
	 * Ctor setup
	 */
	public FrmListKeyInfo( EBiz biz, String keyId )
	{
		this( biz );
		loadKeyIdStr( keyId );
	}


	/**
	 * Loads a PGP key from the key String parameter
	 */
	public void loadKeyIdStr( String Id )
	{
		m_strKeyId = Id;

		if( _isKeyEmpty() )
			return;

		m_strKeyDetail = m_keys.getKeyDetailInfo( m_strKeyId );
		m_txtKeyInfo.setText( m_strKeyDetail );
		m_txtKeyInfo.setCaretPosition( 0 );
		m_cmdDelete.setEnabled( true );
		m_cmdExport.setEnabled( true );
	}

	/**
	 * Prompt the user to input a new PGP key ID then load key.
	 */
	private void _promptKeyInput()
	{
		String _userKey = JOptionPane.showInputDialog( this,
					PGPeBizJava_Prompts.KEY_LOAD_NEW_ID_MSG,
					PGPeBizJava_Prompts.KEY_LOAD_NEW_ID_TITLE,
					JOptionPane.QUESTION_MESSAGE );

		if( _userKey == null )
			return;

		if( _userKey.length() <= 0 )
			return;

		loadKeyIdStr( _userKey );
	}

	/**
	 * Add the command button panel at the bottom of this form
	 */
	private void _addCommandPane()
	{
		final int C_ROW_COUNT = 1;
		final int C_COLUMN_COUNT = 5;

		JPanel _pnlCmdButton = new JPanel( new GridLayout( C_ROW_COUNT, C_COLUMN_COUNT ) );
		getContentPane().add( _pnlCmdButton, BorderLayout.SOUTH );

		_addButtonSelection( _pnlCmdButton, new JButton( PGPeBizJava_Prompts.KEY_LOAD_ID_MSG ),
				PGPeBizJava_RunMode.LOAD_KEY_ID );
		_addButtonSelection( _pnlCmdButton, m_cmdExport, PGPeBizJava_RunMode.EXPORT_KEY );
		_addButtonSelection( _pnlCmdButton, m_cmdDelete, PGPeBizJava_RunMode.DELETE_KEY_ID );
		_addButtonSelection( _pnlCmdButton, new JButton( PGPeBizJava_Prompts.COMMON_REFRESH_MSG ),
				PGPeBizJava_RunMode.LIST_KEY_INFO );
		_addButtonSelection( _pnlCmdButton, new JButton( PGPeBizJava_Prompts.COMMON_CANCEL_MSG ),
				PGPeBizJava_RunMode.CANCEL_OPTION );
	}

	/**
	 * Adds the main view for input/output
	 */
	private void _addKeyInfoView()
	{
		final int C_ROW_COUNT = 1;
		final int C_COLUMN_COUNT = 1;

		JPanel _pnlViews = new JPanel( new GridLayout( C_ROW_COUNT, C_COLUMN_COUNT ) );
		getContentPane().add( _pnlViews, BorderLayout.NORTH );

		m_txtKeyInfo = new JTextArea( m_strKeyDetail, 14, 10 );
		m_txtKeyInfo.setEditable( false );
		JScrollPane _scrKeyView = new JScrollPane( m_txtKeyInfo );
		_pnlViews.add( _scrKeyView );
	}

	/**
	 * Add individual buttons to a panel
	 */
	private void _addButtonSelection( Container _ctn, AbstractButton _btn, final int _btnType )
	{
		_btn.addActionListener( new ActionListener() {
			public void actionPerformed( ActionEvent e ) {
				switch( _btnType )
				{
				case PGPeBizJava_RunMode.CANCEL_OPTION:
					dispose();
					break;

				case PGPeBizJava_RunMode.LIST_KEY_INFO:
					loadKeyIdStr( m_strKeyId );
					break;

				case PGPeBizJava_RunMode.LOAD_KEY_ID:
					_promptKeyInput();
					break;

				case PGPeBizJava_RunMode.DELETE_KEY_ID:
					_deleteKeyId();
					break;

				case PGPeBizJava_RunMode.EXPORT_KEY:
					_exportKeyId();
					break;
				};
			}
		} );
		_ctn.add( _btn );
	}

	/**
	 * Deletes the current PGP key
	 */
	private void _deleteKeyId()
	{
		int _doDelete = JOptionPane.showConfirmDialog( this,
					PGPeBizJava_Prompts.KEY_DELETE_CURRENT_KEY_MSG,
					PGPeBizJava_Prompts.KEY_DELETE_CURRENT_KEY_TITLE,
					JOptionPane.YES_NO_OPTION );


		if( _doDelete == JOptionPane.NO_OPTION )
			return;

		if( m_keys.deleteKey( m_strKeyId ) )
		{
			m_strKeyId = "0";
			m_strKeyDetail = "";
			m_txtKeyInfo.setText( "" );
			m_txtKeyInfo.setCaretPosition( 0 );
			m_cmdDelete.setEnabled( false );
			m_cmdExport.setEnabled( false );
		}
	}

	/**
	 * Determines if the currenty key is empty
	 */
	private boolean _isKeyEmpty()
	{
		if( m_strKeyId.compareTo( "0" ) == 0 )
			return true;

		return false;
	}

	/**
	 * Exports the current PGP key
	 */
	private void _exportKeyId()
	{
		if( _isKeyEmpty() )
			return;

		final int C_EXPORT = 3;

		int _doExport = JOptionPane.showConfirmDialog( null,
								PGPeBizJava_Prompts.KEY_EXPORT_CURRENT_KEY_MSG,
								PGPeBizJava_Prompts.KEY_EXPORT_CURRENT_KEY_TITLE,
								JOptionPane.YES_NO_OPTION );

		if( _doExport == JOptionPane.NO_OPTION )
			return;

		String _dirExport = PGPeBizJava_RunMode.m_dirPaths[ C_EXPORT ];

		if(  m_keys.exportKey( m_strKeyId, _dirExport )  )
			JOptionPane.showMessageDialog( null,
							PGPeBizJava_Prompts.KEY_EXPORT_KEY_SUCCESS_MSG + "\n" + _dirExport + m_strKeyId,
							PGPeBizJava_Prompts.KEY_EXPORT_CURRENT_KEY_TITLE,
							JOptionPane.YES_OPTION );
		else
			JOptionPane.showMessageDialog( null,
							PGPeBizJava_Prompts.KEY_EXPORT_KEY_UNSUCCESS_MSG + "\n" + _dirExport + m_strKeyId,
							PGPeBizJava_Prompts.KEY_EXPORT_CURRENT_KEY_TITLE,
							JOptionPane.YES_OPTION );
	}
}
