/*____________________________________________________________________________
Copyright (C) 2000 Networks Associates Technology, Inc.
All rights reserved.

$Id: FrmListKeys.java,v 1.1 2003/10/27 23:46:20 ishabtay Exp $
____________________________________________________________________________*/

/************************************************************
 *
 * Filename:		FrmListKeys.java
 *
 * Author:		Alex Faieta
 * Date:		September 12, 2001
 * Editor:		Notepad
 * Java Version:	Sun Java 1.3.1
 * Description:
 *
 ************************************************************/

// Sun Java packages
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.event.MouseListener;
import java.awt.event.MouseEvent;
import java.awt.BorderLayout;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.GridLayout;
import javax.swing.AbstractButton;
import javax.swing.JButton;
import javax.swing.JInternalFrame;
import javax.swing.JList;
import javax.swing.JOptionPane;
import javax.swing.JScrollPane;
import javax.swing.JPanel;

// PGPeBizJava packages
import com.mcafee.ebs.EBiz;


public class FrmListKeys extends JInternalFrame
{
	private JList		m_allKeyList	= null;
	private PGPKeys		m_keys		= null;
	private EBiz		m_biz		= null;
	private JButton		m_cmdDelete	= null;



	/**
	 * Ctor setup
	 */
	public FrmListKeys( EBiz biz )
	{
		super( PGPeBizJava_Prompts.FORM_KEY_LIST_KEYS_CAPTION, false, true, false, true );
		setSize( 500, 290 );
		setDefaultCloseOperation( DISPOSE_ON_CLOSE );
		getContentPane().setLayout( new BorderLayout() );

		m_biz = biz;
		m_keys = new PGPKeys( biz );
		m_allKeyList = new JList();
		m_cmdDelete = new JButton( PGPeBizJava_Prompts.KEY_DELETE_ID_MSG );

		_addCommandPane();
		_addKeyView();
		_loadAllKeyItems();

		show();
	}

	/**
	 * Add the command button panel at the bottom of this form
	 */
	private void _addCommandPane()
	{
		final int C_ROW_COUNT = 1;
		final int C_COLUMN_COUNT = 2;

		JPanel _pnlCmdButton = new JPanel( new GridLayout( C_ROW_COUNT, C_COLUMN_COUNT ) );
		getContentPane().add( _pnlCmdButton, BorderLayout.SOUTH );

		_addButtonSelection( _pnlCmdButton, new JButton( PGPeBizJava_Prompts.KEY_VIEW_KEY_INFO_MSG ), PGPeBizJava_RunMode.LIST_KEY_INFO );
		_addButtonSelection( _pnlCmdButton, m_cmdDelete , PGPeBizJava_RunMode.DELETE_KEY_ID );
		_addButtonSelection( _pnlCmdButton, new JButton( PGPeBizJava_Prompts.COMMON_REFRESH_MSG ), PGPeBizJava_RunMode.LIST_ALL_KEYS );
		_addButtonSelection( _pnlCmdButton, new JButton( PGPeBizJava_Prompts.COMMON_CANCEL_MSG ), PGPeBizJava_RunMode.CANCEL_OPTION );
	}

	/**
	 * Adds the main view for input/output
	 */
	private void _addKeyView()
	{
		final int C_ROW_COUNT = 2;
		final int C_COLUMN_COUNT = 1;
		final int C_DOUBLE_CLICK = 2;

		JPanel _pnlViews = new JPanel( new GridLayout(  C_ROW_COUNT, C_COLUMN_COUNT ) );
		getContentPane().add( _pnlViews, BorderLayout.NORTH );


		m_allKeyList.addMouseListener( new MouseListener() {
			public void mouseClicked( MouseEvent e ) {
				if( e.getClickCount() == C_DOUBLE_CLICK ) {
					_viewSelectedKeys();
				}
			}
			public void mousePressed( MouseEvent e ) { }
			public void mouseReleased( MouseEvent e ) { }
			public void mouseEntered( MouseEvent e ) { }
			public void mouseExited( MouseEvent e ) { }
		} );


		m_allKeyList.setVisibleRowCount( 12 );
		JScrollPane _scrKeyList = new JScrollPane( m_allKeyList );
		_pnlViews.add( _scrKeyList );
	}

	/**
	 * Loads all PGP keys and places them into the list view
	 */
	private void _loadAllKeyItems()
	{
		m_keys.loadKeys();
		m_allKeyList.setListData( m_keys.getKeyItems() );

		if( m_keys.getTotalCount() >= 1 )
			m_allKeyList.setEnabled( true );
		else
			m_allKeyList.setEnabled( false );
	}

	/**
	 * Add individual buttons to a panel
	 */
	private void _addButtonSelection( Container _ctn, AbstractButton _btn, final int _btnType )
	{
		_btn.addActionListener( new ActionListener() {
			public void actionPerformed( ActionEvent e ) {
				switch( _btnType )
				{
				case PGPeBizJava_RunMode.CANCEL_OPTION:
					dispose();
					break;

				case PGPeBizJava_RunMode.LIST_ALL_KEYS:
					_loadAllKeyItems();
					break;

				case PGPeBizJava_RunMode.LIST_KEY_INFO:
					_viewSelectedKeys();
					break;

				case PGPeBizJava_RunMode.DELETE_KEY_ID:
					_deleteSelectedKeys();
					break;
				};
			}
		} );
		_ctn.add( _btn );
	}

	/**
	 * View the selected PGP keys within the list view
	 */
	private void _viewSelectedKeys()
	{
		if( m_allKeyList.getSelectedIndex() == -1 )
			return;


		FrmListKeyInfo _frmKeyDetail = null;
		String _info = null;
		Object[] _selectedKeys = m_allKeyList.getSelectedValues();

		for( int idx=0; idx < _selectedKeys.length; idx++ )
		{
			_info = m_keys.extractKeyId( (String) _selectedKeys[ idx ] );
			_frmKeyDetail = new FrmListKeyInfo( m_biz, _info );
			getDesktopPane().add( _frmKeyDetail  );
		}
	}

	/**
	 * Deletes the selected PGP keys within the list view
	 */
	private void _deleteSelectedKeys()
	{
		if( m_allKeyList.getSelectedIndex() == -1 )
			return;

		// prompt user to continue with the deletion
		int _doDelete = JOptionPane.showConfirmDialog( this,
					PGPeBizJava_Prompts.KEY_DELETE_MULTI_KEYS_MSG,
					PGPeBizJava_Prompts.KEY_DELETE_MULTI_KEYS_TITLE,
					JOptionPane.YES_NO_OPTION );

		if( _doDelete == JOptionPane.NO_OPTION )
			return;


		Object[] _selectedKeys = m_allKeyList.getSelectedValues();


		// delete each selected PGP Key
		for( int idx=0; idx < _selectedKeys.length; idx++ )
		{
			m_keys.deleteKey( m_keys.extractKeyId( (String) _selectedKeys[ idx ] ) );
		}

		_loadAllKeyItems();
	}
}
