/*____________________________________________________________________________
Copyright (C) 2000 Networks Associates Technology, Inc.
All rights reserved.

$Id: PGPEncryption.java,v 1.1 2003/10/27 23:46:20 ishabtay Exp $
____________________________________________________________________________*/

/************************************************************
 *
 * Filename:		PGPEncryption.java
 *
 * Author:		Alex Faieta
 * Date:		September 5, 2001
 * Editor:		Notepad
 * Java Version:	Sun Java 1.3.1
 * Description:
 *
 ************************************************************/

// Sun Java packages
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;

// PGPeBizJava packages
import com.mcafee.ebs.EBiz;


public class PGPEncryption
{
	private PGPeBizJava_CmdlineArgs	m_cmd	= null;
	private PGPRun			m_run	= null;
	private final int		C_EOF	= -1;


	/**
	 * Ctor setup
	 */
	public PGPEncryption( EBiz biz )
	{
		m_cmd = new PGPeBizJava_CmdlineArgs();
		m_run = new PGPRun( biz );
	}

	/**
	 * Encrypt single files to the directory parameter
	 */
	public boolean encrypt( File fileObj, String dirEncryptTo )
	{
		if( ! fileObj.isFile() )
			return false;

		new Util().isDirPathValid( dirEncryptTo );

		String _runCmd = m_cmd.C_ENCRYPT_CMDLINE + " " +
				 m_cmd.C_ENCRYPT_ARMOR_CMDLINE + " " +
				 m_cmd.C_CONVENTIONAL_CMDLINE + " " +
				 m_cmd.C_CONVENTIONAL_PASSPHRASE_CMDLINE + " \"foobar\"";

		String _output = m_run.runCommand(	_runCmd,
							_getFileContents( fileObj )	);

		String _newFileName = new String( dirEncryptTo + fileObj.getName() + m_cmd.C_ARMOR_FILE_EXTENSION );
		return _setFileContents( _newFileName, _output );
	}

	/**
	 * Decrypt single files to the directory parameter
	 */
	public boolean decrypt( File fileObj, String dirDecryptTo )
	{
		if( ! fileObj.isFile() )
			return false;

		new Util().isDirPathValid( dirDecryptTo );

		String _runCmd = m_cmd.C_DECRYPT_CMDLINE + " " +
				 m_cmd.C_CONVENTIONAL_PASSPHRASE_CMDLINE + " \"foobar\"";


		String _output = m_run.runCommand(	_runCmd,
							_getFileContents( fileObj ) );

		String _newFileName = new String( dirDecryptTo + _removeFileExt( fileObj ) );
		return _setFileContents( _newFileName, _output );
	}

	/**
	 * Wipe a single file from the parameter
	 */
	public boolean wipeFile( File fileObj )
	{
		if( ! fileObj.isFile() )
			return false;

		String _runCmd = m_cmd.C_WIPE_CMDLINE + " \"" + fileObj.getPath() + "\"";

		return m_run.isRunCommand( _runCmd );
	}

	/**
	 * Removes the file extension from the parameter
	 */
	private String _removeFileExt( File _fileName )
	{
		int _idxDotExt = _fileName.getName().lastIndexOf( "." );

		if( _idxDotExt == -1 )
			return _fileName.getName();


		return new String( _fileName.getName().substring( 0, _idxDotExt ) );
	}

	/**
	 * Gets the contents from the File supplied
	 */
	private String _getFileContents( File _file )
	{
		if( ! _file.isFile() )
			return new String();

		StringBuffer _strBuff = new StringBuffer();

		// open the file
		try {
			FileReader _fileEncrypt = new FileReader( _file );

			int _idx = 1;
			int _ch = 0;
			do {
				_ch = _fileEncrypt.read();
				_strBuff.append( (char)_ch );
			} while( ++_idx <= _file.length() );

			_fileEncrypt.close();
		} catch( FileNotFoundException _excNoFile ) {
			System.err.println( _excNoFile.toString() );
		} catch( IOException _ioexc ) {
			System.err.println( _ioexc.toString() );
		}

		return new String( _strBuff );
	}

	/**
	 * Replaces the contents for a file
	 */
	private boolean _setFileContents( String _fileName, String _contents )
	{
		try {
			FileWriter _newFile = new FileWriter( _fileName );

			_newFile.write( _contents );
			_newFile.close();
			return true;
		} catch( IOException _ioexc ) {
			System.err.println( _ioexc.toString() );
		}

		return false;
	}

	/**
	 * Compares two files supplied of a character-by-character
	 * comparison
	 */
	public boolean isCompareValid( File _encrypt, File _decrypt )
	{
		if( ! _encrypt.isFile() || ! _decrypt.isFile() )
			return false;

		try {
			FileReader _readEncrypt = new FileReader( _encrypt );
			FileReader _readDecrypt = new FileReader( _decrypt );

			while( _readEncrypt.ready() || _readDecrypt.ready() )
			{
				if( _readEncrypt.read() == _readDecrypt.read() )
					if( ! _readEncrypt.ready() && ! _readDecrypt.ready() )
						return true;
			}
		} catch( FileNotFoundException _excNoFile ) {
			System.err.println( _excNoFile.toString() );
		} catch( IOException _ioexc ) {
			System.err.println( _ioexc.toString() );
		}

		return false;
	}
}
