/*____________________________________________________________________________
Copyright (C) 2000 Networks Associates Technology, Inc.
All rights reserved.

$Id: PGPKeys.java,v 1.1 2003/10/27 23:46:20 ishabtay Exp $
____________________________________________________________________________*/

/************************************************************
 *
 * Filename:		PGPKeys.java
 *
 * Author:		Alex Faieta
 * Date:		September 12, 2001
 * Editor:		Notepad
 * Java Version:	Sun Java 1.3.1
 * Description:
 *
 ************************************************************/

// Sun Java packages
import java.awt.List;
import java.io.File;

// PGPeBizJava packages
import com.mcafee.ebs.EBiz;


public class PGPKeys
{
	private int			m_currentPosition	= 0;
	private List			m_list			= null;
	private PGPeBizJava_CmdlineArgs m_cmd			= new PGPeBizJava_CmdlineArgs();
	private PGPRun 			m_run			= null;
	private String			m_cmdString		= null;


	/**
	 * Ctor setup
	 */
	public PGPKeys( EBiz biz )
	{
		m_run = new PGPRun( biz );
		m_list = new List();
		m_cmdString = new String();
	}


	/**
	 * Loads all the PGP keys
	 */
	public void loadKeys()
	{
		// Run the PGP list command
		String _output = m_run.runCommand( m_cmd.C_KEY_LIST_CMDLINE,
							m_cmdString );

		m_list.removeAll();

		final String C_NEWLINE = "\n";
		final String C_END_KEY_LIST = "\n\n";
		int _endKeyStrIdx = _output.indexOf( C_NEWLINE );
		int _startKeyStrIdx = _endKeyStrIdx + 1;

		/**
		 * Loop through the entire list command, and search for
		 * individual keys, and add them to the list
		 */
		for(;;) {

			if( _output.indexOf( C_END_KEY_LIST ) > _endKeyStrIdx )
			{
				_startKeyStrIdx = _endKeyStrIdx + 1;
				_endKeyStrIdx = _output.indexOf( C_NEWLINE, _startKeyStrIdx );
				m_list.add( new String( _output.substring( _startKeyStrIdx, _endKeyStrIdx ) ) );
			}
			else
				break;
		}
	}

	/**
	 * Gets the list information of a key, based on an index
	 */
	public String getKeyInfo( int idx )
	{
		if( idx < 0 || (getTotalCount()-1) < idx )
			return new String();

		return m_list.getItem( idx );
	}

	/**
	 * Get all the items within the list
	 */
	public String[] getKeyItems()
	{
		return m_list.getItems();
	}

	/**
	 * Gets the count of list
	 */
	public int getTotalCount()
	{
		return m_list.getItemCount();
	}

	/**
	 * Gets the detailed information of the key, based on
	 * the index within the list
	 */
	public String getKeyDetailInfo( int idx )
	{
		return m_run.runCommand( m_cmd.C_KEY_DETAIL_CMDLINE + " \"" +
					 extractKeyId( getKeyInfo( idx ) ) + "\""
					);
	}

	/**
	 * Gets the PGP Id of an individual key info
	 */
	public String extractKeyId( String keyInfo )
	{
		final String C_KEYINFO_END_FLAG = "]";
		final String C_EMPTY_CHAR = " ";

		int _startKey = keyInfo.indexOf( C_KEYINFO_END_FLAG ) + 2;

		return keyInfo.substring( _startKey, keyInfo.indexOf( C_EMPTY_CHAR, _startKey ) );
	}

	/**
	 * Gets the detailed information of a key, based on
	 * the String of a key id
	 */
	public String getKeyDetailInfo( String keyId )
	{
		return m_run.runCommand( PGPeBizJava_CmdlineArgs.C_KEY_DETAIL_CMDLINE + " \"" + keyId + "\""  );
	}

	/**
	 * Adds a new PGP key
	 */
	public boolean addNewKey( String userId, String passphrase, String keyType, String keySize )
	{
		m_cmdString = m_cmd.C_KEY_GEN_CMDLINE + " " +
				m_cmd.C_KEY_USERID_CMDLINE + " \"" + userId + "\" " +
				m_cmd.C_KEY_PASSPHRASE_CMDLINE + " \"" + passphrase + "\" " +
				m_cmd.C_KEY_KEY_TYPE_CMDLINE + " \"" + keyType + "\" " +
				m_cmd.C_KEY_KEY_SIZE_CMDLINE + " \"" + keySize + "\"";

		return m_run.isRunCommand( m_cmdString );
	}

	/**
	 * Gets the active command line parameter
	 */
	public String getCmdInputString()
	{
		return m_cmdString;
	}

	/**
	 * Deletes a PGP key based on the String ID
	 */
	public boolean deleteKey( String Id )
	{
		m_cmdString = m_cmd.C_KEY_REMOVE_CMDLINE + " \"" + Id + "\" " +
				m_cmd.C_KEY_FORCE_CMDLINE + " \"" + m_cmd.C_KEY_WITH_PRIVATE_CMDLINE + "\"";

		return m_run.isRunCommand( m_cmdString );
	}

	/**
	 * Exports the PGP key to the directory parameter.
	 * The filename is the PGP key ID.
	 */
	public boolean exportKey( String Id, String dirExportTo )
	{
		// if the directory does not exist, create it
		new Util().isDirPathValid( dirExportTo );

		m_cmdString = m_cmd.C_KEY_EXPORT_CMDLINE + " \"" + Id + "\" " +
				m_cmd.C_OUTPUT_CMDLINE + " \"" + dirExportTo + Id + "\"";

		return m_run.isRunCommand( m_cmdString );
	}

	/**
	 * Gets the signature detail of the PGP key String.
	 */
	public String getSigDetail( String Id )
	{
		m_cmdString = m_cmd.C_KEY_SIG_DETAIL_CMDLINE + " \"" + Id + "\"";

		return m_run.runCommand( m_cmdString );
	}

	/**
	 * Import a single PGP key from a file
	 */
	public boolean importKey( File fileObj )
	{
		if( ! fileObj.isFile() )
			return false;

		m_cmdString = m_cmd.C_KEY_ADD_CMDLINE + " " +
				m_cmd.C_MULTI_CMDLINE + " \"" + fileObj.getPath() + "\"";

		return m_run.isRunCommand( m_cmdString );
	}
}
