/*____________________________________________________________________________
Copyright (C) 2000 Networks Associates Technology, Inc.
All rights reserved.

$Id: Util.java,v 1.1 2003/10/27 23:46:21 ishabtay Exp $
____________________________________________________________________________*/

/************************************************************
 *
 * Filename:		Util.java
 *
 * Author:		Alex Faieta
 * Date:		September 24, 2001
 * Editor:		Notepad
 * Java Version:	Sun Java 1.3.1
 * Description:		
 *
 ************************************************************/

// Sun Java packages
import java.awt.event.KeyEvent;
import java.io.File;
import javax.swing.text.JTextComponent;
import javax.swing.JFileChooser;


public final class Util
{
	private static final String C_ACTIONCMD_END	= "text: ";
	private static final int C_ACTIONCMD_END_LENGTH	= 6;
	
	/**
	 * Ctor setup
	 */
	public Util()
	{ }

	/**
	 * Gets the Menu caption from an object event String.
	 */
	public String _getMenuSelection( String mnu )
	{
		return new String(
			mnu.substring(
				mnu.indexOf( C_ACTIONCMD_END ) + C_ACTIONCMD_END_LENGTH,
						mnu.length()
			)
		);
	}
	
	/**
	 * Gets a String of a reverse search, based on the number
	 * of times to remove a string.
	 * 
	 * ex. Used to remove a user supplied amount of
	 *		directorys (numDirRemove), when searching for
	 *		the directory slash (dirSlash), from the original
	 *		directory (dir).
	 */
	public String getReverseSearchStr( String dir, int numDirRemove, String dirSlash )
	{
		String _newDir = new String();
		for( int idx=dir.length(); idx >= 0; idx-- )
		{
			idx = dir.lastIndexOf( dirSlash, idx );
			_newDir = dir.substring( 0, idx );
			if( --numDirRemove <= 0 ) break;
		}
		
		return _newDir;
	}
	
	/**
	 * Determines if the textbox parameter is empty of data
	 */
	public boolean isTextBoxEmpty( JTextComponent txt )
	{
		if( txt.getText().length() <= 0 )
			return true;
		
		return false;
	}
	
	/**
	 * Returns a String that appends a CR (carriage return)
	 * before each LF (line feed)
	 */
	public String addCarriageReturn( String str )
	{
		System.out.println( str );
		final int C_LINE_FEED = 10;
		
		String _newStr = new String();
		
		for( int idx=0; idx < str.length(); idx++ )
		{
			if( idx == str.indexOf( C_LINE_FEED, idx ) )
				_newStr += (char)KeyEvent.VK_ENTER;
			
			_newStr += str.charAt( idx );
		}
		
		return _newStr;
	}

	/**
	 * Gets the current user working directory
	 */
	public String getCurrentDir()
	{
		return System.getProperty( "user.dir" );
	}
	
	/**
	 * Gets an array of Files.
	 * Starts at the current user working directory.
	 */
	public File[] selectFiles()
	{
		return this.selectFiles( this.getCurrentDir() );
	}
	
	/**
	 * Gets an array of Files.
	 * Starts at the directory supplied.
	 */
	public File[] selectFiles( String dir )
	{
		JFileChooser _dlgOpenFile = new JFileChooser( dir );
		_dlgOpenFile.setMultiSelectionEnabled( true );

		int _fileSelection = _dlgOpenFile.showOpenDialog( null );
		
		switch( _fileSelection )
		{
		case JFileChooser.APPROVE_OPTION:
			return _dlgOpenFile.getSelectedFiles();
		};
		
		return new File[] { };
	}

	/**
	 * Checks if the directory exists. If the directory does not exists
	 * create directory given in argument.
	 */
	public boolean isDirPathValid( String _strDir )
	{
		File _dir = new File( _strDir );

		if( ! _dir.isDirectory() )
			return _dir.mkdir();

		return true;
	}
}
