#!/bin/sh

#
# McAfee E-Business Server Uninstall Script
#

. ./platform.sh

if [ ! "$WHOAMI" = "" ]; then
	USERNAME=`$WHOAMI`
	if [ ! "$USERNAME" = "root" -a "$1" != "-f" ]; then
		$ECHO
		$ECHO "This script contains statements which should be executed"
		$ECHO "by root. It is recommended that you log in as root to"
		$ECHO "continue uninstallation."
		$ECHO
		$ECHO "Proceed anyway? [y/N] \c"
		read ANSWER
		while [ 1 ]; do
			ANSWER=`$ECHO $ANSWER | $TR "/[a-z]/" "/[A-Z]/"`
			case $ANSWER in
				Y|YES)
					break
					;;
				N|NO|"")
					$ECHO "Uninstall cancelled."
					exit 1
					;;
				*)
					;;
			esac
			$ECHO "Proceed anyway? [y/N] \c"
			read ANSWER
		done
	elif [ ! "$USERNAME" = "root" -a "$1" = "-f" ]; then
		$ECHO "Uninstall cancelled."
		exit 1
	fi
fi

$ECHO
$ECHO "This script uninstalls the McAfee E-Business Server, including"
	if [ "$PGPSDKD" = "Y" ]; then
		$ECHO "the ebssdkd, \c"
	fi
$ECHO "shared libraries, header files and the ebs binary. "
$ECHO
$ECHO "Configuration files are NOT removed by this script."
$ECHO
if [ "$1" = "-f" ] ; then
	RMF="-f"
else
	RMF=""
fi
if [ "$1" != "-f" ] ; then
	$ECHO "Would you like to proceed? [y/N] \c"
	read ANSWER
	while [ 1 ]; do
		ANSWER=`$ECHO $ANSWER | $TR "/[a-z]/" "/[A-Z]/"`
		case $ANSWER in
			Y|YES)
				break
				;;
			N|NO|"")
				$ECHO "Uninstall cancelled."
				exit 1
				;;
			*)
				;;
		esac
		$ECHO "Would you like to proceed? [y/N] \c"
		read ANSWER
	done
fi

if [ -f "/usr/local/sbin/ebsadmin" ]; then
	ADMINPID=`ps -ef | grep "ebsadmin" | grep -v "grep" | awk '{print $2}'`
	if [ "$ADMINPID" != "" ]; then
		$ECHO "Stopping the ebsadmin daemon"
		kill $ADMINPID
		sleep 5
	fi
	$ECHO "Removing the ebsadmin binary"
	$RM $RMF /usr/local/sbin/ebsadmin
	if [ $? != 0 ]; then 
		ERROR=1; 
	fi
	$RMDIR /usr/local/sbin > /dev/null 2>/dev/null && $ECHO "Removed empty /usr/local/sbin"
	SOMETHINGDONE=1
fi
if [ -f "$INITDIR/ebssdkd" ]; then
	$ECHO "Stopping the ebssdkd daemon"
	$INITDIR/ebssdkd stop
	sleep 5
	$ECHO "Removing the startup script for ebssdkd"
	$RM -f $INITDIR/ebssdkd
	if [ $? != 0 ]; then ERROR=1; fi
	SOMETHINGDONE=1
fi
if [ -f "/usr/local/ebs/ebscache" ]; then
	CACHEPID=`ps -ef | grep "ebscache" | grep -v "grep" | awk '{print $2}'`
	if [ "$CACHEPID" != "" ]; then
		$ECHO "Stopping the ebscache"
		kill $CACHEPID
		sleep 5
	fi
fi
if [ $IS_SYMLINK "$STARTUPDIR/S10pgpsdkd" ]; then
	$ECHO "Removing symbolic links to the ebssdkd startup script"
	$RM -f $STARTUPDIR/S10pgpsdkd
	if [ $? != 0 ]; then ERROR=1; fi
	SOMETHINGDONE=1
fi

if [ $IS_SYMLINK "$BINDIR/pgp" ]; then
	$ECHO "Removing pgp script compatibility symlink"
	$RM -f $BINDIR/pgp
	if [ $? != 0 ]; then ERROR=1; fi
	SOMETHINGDONE=1
fi

if [ -h "$STARTUPDIR/S10pgpsdkd" ]; then
	$RM -f $STARTUPDIR/S10pgpsdkd
	if [ $? != 0 ]; then ERROR=1; fi
	SOMETHINGDONE=1
fi

if [ -f "/usr/local/sbin/EBSVARS" ]; then
	$ECHO "Removing EBS vars file"
	$RM $RMF /usr/local/sbin/EBSVARS
	if [ $? != 0 ]; then
		ERROR=1;
	fi
	SOMETHINGDONE=1
fi

if [ -f "/usr/local/sbin/ebssdkd" ]; then
	$ECHO "Removing the ebssdkd binary"
	$RM $RMF /usr/local/sbin/ebssdkd
	if [ $? != 0 ]; then 
		ERROR=1; 
	fi
	$RMDIR /usr/local/sbin > /dev/null 2>/dev/null && $ECHO "Removed empty /usr/local/sbin"
	SOMETHINGDONE=1
fi

$RM -f $PGPSDKPIPE 2>&1 > /dev/null

if [ "$SOMETHINGDONE" = "1" ]; then
	$ECHO
fi

$ECHO "Removing symlink for libpath /usr/lib/ebs: \c"
( $RM $RMF /usr/lib/ebs && $ECHO ok && SOMETHINGDONE=1) || ERROR=1

if [ -f /etc/ld.so.conf ]; then
	if $GREP "/usr/lib/ebs" /etc/ld.so.conf > /dev/null; then
		$ECHO "Removing library directory from /etc/ld.so.conf..."
		cp /etc/ld.so.conf /etc/ld.so.conf~
		if ( $GREP -v '/usr/lib/ebs' /etc/ld.so.conf > /etc/ld.so.conf.ebs && mv /etc/ld.so.conf.ebs /etc/ld.so.conf && $ECHO "   ...and updating /etc/ld.so.cache...\c" && ldconfig ); then
			$ECHO "done."
			SOMETHINGDONE=1
		else
			$ECHO "WARNING: could not remove library directory from /etc/ld.so.conf."
			$ECHO "Restoring /etc/ld.so.conf: \c"
			( mv /etc/ld.so.conf~ /etc/ld.so.conf && $ECHO ok ) || echo "ACK!  Despite my best efforts, I may have munged /etc/ld.so.conf due to the errors above :( "
			ERROR=1
			$ECHO
			sleep 2
		fi
	fi
fi

$ECHO "Removing library directory /usr/local/ebs/lib: \c"
( $RM -rf /usr/local/ebs/lib && $ECHO ok ) || ERROR=1;

$ECHO "Removing header files from /usr/local/ebs/include...\c"
if ( $RM -rf /usr/local/ebs/include ); then
	$ECHO "done."
	SOMETHINGDONE=1
else
	ERROR=1; 
fi

$ECHO

$ECHO "Removing additional information files from /usr/local/ebs..."
# This file was installed by previous EBS builds, check for it here
if [ -f "/usr/local/ebs/SampleKeys.asc" ]; then
( $ECHO " - Sample keys: \c" && rm $RMF /usr/local/ebs/SampleKeys.asc && $ECHO ok && SOMETHINGDONE=1 ) || ERROR=1
fi
( $ECHO " - LICENSE: \c" && rm $RMF /usr/local/ebs/LICENSE && $ECHO ok && SOMETHINGDONE=1 ) || ERROR=1
$ECHO "...done."

$ECHO

$ECHO "Removing man page symlink: \c"
( $RM $RMF $MANPATH/man1/ebs.1 && echo ok && SOMETHINGDONE=1 ) || echo "\t\t(not critical)"

$ECHO "Removing man page directory: \c"
( $RM -rf /usr/local/ebs/man && echo ok && SOMETHINGDONE=1 ) || ERROR=1

$ECHO "Removing documentation: \c"
( $RM -rf /usr/local/ebs/docs && echo ok && SOMETHINGDONE=1 ) || ERROR=1

$ECHO "Removing sample code from /usr/local/ebs/samples/: \c"
( $RM -rf /usr/local/ebs/samples && echo ok && SOMETHINGDONE=1 ) || ERROR=1

$ECHO "Removing binaries from /usr/local/ebs and symlinks from $BINDIR..."

$ECHO " - ebsadmin: \c"
( rm $RMF /usr/local/ebs/ebsadmin $BINDIR/ebsadmin && $ECHO ok ) || ERROR=1;

$ECHO " - ebs: \c"
( rm $RMF /usr/local/ebs/ebs $BINDIR/ebs && $ECHO ok ) || ERROR=1;

$ECHO " - ebsreader: \c"
( rm $RMF /usr/local/ebs/ebsreader $BINDIR/ebsreader && $ECHO ok ) || ERROR=1

if [ "$PGPSDKD" = "Y" ]; then
	$ECHO " - ebscache: \c"
	( rm $RMF /usr/local/ebs/ebscache $BINDIR/ebscache  && $ECHO ok ) || ERROR=1
fi
$ECHO "...done."

$ECHO "Removing JAR files..."

$ECHO " - McAfeeEBS.jar: \c"
( rm $RMF /usr/local/ebs/McAfeeEBS.jar && $ECHO ok ) || ERROR=1;
$ECHO " - commons-codec-1.2.jar: \c"
( rm $RMF /usr/local/ebs/commons-codec-1.2.jar && $ECHO ok ) || ERROR=1;
$ECHO " - McAfeeEBSGUI.jar: \c"
( rm $RMF /usr/local/ebs/McAfeeEBSGUI.jar && $ECHO ok ) || ERROR=1;

$ECHO "Removing license file from /usr/local/ebs... \c"
( rm $RMF /usr/local/ebs/EBusSvr.lic && $ECHO ok ) || ERROR=1;

$ECHO


if [ "$ERROR" = 1 ]; then
	$ECHO "One or more errors have been detected.  Please review the messages above"
	$ECHO "to ensure that the uninstall has completed successfully."

	exit 1
else 
	cd && $ECHO "Changed current directory to `pwd`" && $ECHO
	$ECHO "Removing the uninstaller from /usr/local/ebs/uninstall/: \c"
	( $RM -rf /usr/local/ebs/uninstall && $ECHO ok ) || echo "Failed to remove the uninstaller. "
	$ECHO "Removing /usr/local/ebs: \c"
	( $RMDIR /usr/local/ebs && $ECHO "Removed empty /usr/local/ebs" ) || $ECHO "WARNING: Configuration files are not automatically removed"
	$ECHO
fi

if [ "$SOMETHINGDONE" = 1 ]; then
	$ECHO "Uninstall complete."
fi
